@@ -1,4 +1,3 @@
-
 import re
 import datetime
 from decimal import Decimal
@@ -77,14 +76,14 @@ def iso8601_repr(timedelta):
         )),
       )
 
-    result = ''
+    result = []
     for category, subcats in formatting:
         result += category
         for format, value in subcats:
             if value:
-                result += '%d%c' % (value, format)
+                result.append('%d%c' % (value, format))
 
-    return result
+    return result.join("")
 
 def parse(string):
     """
@@ -165,6 +164,14 @@ def percentage(obj1, obj2):
     
     return divide(obj1 * 100, obj2, as_float=True)
 
+def decimal_percentage(obj1, obj2):
+    """
+    >>> decimal_percentage(datetime.timedelta(2), datetime.timedelta(4))
+    Decimal('50.0')
+    """
+    return Decimal(str(percentage(obj1, obj2)))
+    
+    
 def multiply(obj, val):
     """
     Allows for the multiplication of timedeltas by float values.
